start_registration

Function start_registration 

pub async fn start_registration<S: PasskeyStore + ?Sized>(
    store: &S,
    user_id: &str,
    username: &str,
    display_name: &str,
    config: &PasskeyConfig,
    now_ms: i64,
) -> Result<PublicKeyCredentialCreationOptions>
Initiates a new passkey registration.

Returns the options that must be sent to the WebAuthn client (navigator.credentials.create). It also saves the registration session state to the provided store.