pub async fn start_login<S: PasskeyStore + ?Sized>(
store: &S,
config: &PasskeyConfig,
now_ms: i64,
) -> Result<PublicKeyCredentialRequestOptions>Expand description
Initiates a passkey login flow.
Returns the options that must be sent to the WebAuthn client (navigator.credentials.get).
It saves a login session state keyed by the challenge.